.. _ref-homepage:

mlsauce's documentation
======================================

.. image:: https://img.shields.io/pypi/v/mlsauce
      :target: https://pypi.org/project/mlsauce/
      :alt: Latest PyPI version


.. image:: https://img.shields.io/pypi/l/mlsauce
      :target: https://github.com/thierrymoudiki/mlsauce/blob/master/LICENSE   
      :alt: PyPI - License


.. image:: https://pepy.tech/badge/mlsauce
      :target: https://pepy.tech/project/mlsauce
      :alt: Number of PyPI downloads



This package contains miscellaneous Statistical/Machine Learning tools. 
`mlsauce`'s **source code** is `available on GitHub <https://github.com/thierrymoudiki/mlsauce>`_, and you can read blog posts about it `on this blog <https://thierrymoudiki.github.io/blog/>`_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation   
   usage
   apidocumentation
   modules
   contributing   
   license
   history


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
